==> plplot-5.10.0.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_72.js <==
var searchData=
[
  ['r',['r',['../structtriangle.html#a8c113023de81330c683c9c81f878e50c',1,'triangle::r()'],['../structcircle.html#a5f252f6cf93b81949dbf334c74931f18',1,'circle::r()'],['../structplplot_1_1__N9.html#a01fbe78b7661462acf48a6ef1e6f69f8',1,'plplot::_N9::r()'],['../structPLColor.html#a7b9027cf28c331d71c22b00b51676b66',1,'PLColor::r()']]],
  ['ranma',['ranma',['../structPLStream.html#aec2efdbc2ca51f988a82ce7ec78f0453',1,'PLStream']]],
  ['ranmi',['ranmi',['../structPLStream.html#a9dba1033a4c746fca6c24651ec6db2f7',1,'PLStream']]],
  ['rasterize_5fimage',['rasterize_image',['../structPLCairo.html#a8f1b530005cb096156a35e18bb8d779e',1,'PLCairo::rasterize_image()'],['../cairo_8c.html#acca2891d8180befce6f21603e0b1eea9',1,'rasterize_image():&#160;cairo.c']]],
  ['rband',['rband',['../structPlFrame.html#aa776906f93a788fa34b76bdda136966d',1,'PlFrame::rband()'],['../structPlPlotter.html#af9fc308a1e078617e9d7429b55c3b832',1,'PlPlotter::rband()']]],
  ['rband_5fpt',['rband_pt',['../structPlFrame.html#a917bc8ae7665e11c5ad9c957e82c26a5',1,'PlFrame::rband_pt()'],['../structPlPlotter.html#a64a6d749895142d0b745876e7bcd4530',1,'PlPlotter::rband_pt()']]],
  ['ready',['ready',['../classwxPLDevBase.html#aa6654b36b2549ca795e149847422d2e8',1,'wxPLDevBase']]],
  ['red',['red',['../structcdImageStruct.html#a9c162fd0660559d959bbf9d90e3fc071',1,'cdImageStruct']]],
  ['refresh',['refresh',['../classwxPLplotWindow.html#a807e8abcf641953214b24d583cd70e4e',1,'wxPLplotWindow']]],
  ['refx',['refx',['../structEscText.html#a285ddb4ae4df1f679caac4f8da861d1e',1,'EscText']]],
  ['refy',['refy',['../structEscText.html#a139c59f7c3157c5f66f4e82dae4776ea',1,'EscText']]],
  ['relief',['relief',['../structPlFrame.html#a41508f51c2fb15d19c743dc7c2bea360',1,'PlFrame::relief()'],['../structPlPlotter.html#a77816130e2cf511b4c982239e9044f48',1,'PlPlotter::relief()']]],
  ['replot',['replot',['../gcw_8c.html#a6af9bfa40af1e6e231cf593311721b51',1,'gcw.c']]],
  ['resizing',['resizing',['../classwxPLDevBase.html#ad10bca74735e9c8bfd5a847b3037c604',1,'wxPLDevBase']]],
  ['result',['result',['../structplplot_1_1__N11.html#aead102f090672f500c41981a2eebcdb1',1,'plplot::_N11::result()'],['../structPLBufferingCB.html#a30692e8a3aa17c0c8082a5d0c40328df',1,'PLBufferingCB::result()']]],
  ['return_5fcode',['return_code',['../tclAPI_8c.html#a934c111b1421c6aa91507fabd5c96deb',1,'tclAPI.c']]],
  ['rotate',['rotate',['../structarc__struct.html#ab0caa02f48b247f181d80573eef17d28',1,'arc_struct']]],
  ['rotation',['rotation',['../classwxPLDevBase.html#a99a7c535aea8c138bf68a67e11eca908',1,'wxPLDevBase']]],
  ['rw_5fcmap',['rw_cmap',['../structXwDisplay.html#a84faf4f40f4aa3cf96710c956107e2af',1,'XwDisplay']]],
  ['rx',['rx',['../namespacePlframe.html#a3c48e474361f6fca6966964d609038fe',1,'Plframe']]],
  ['ry',['ry',['../namespacePlframe.html#afa4b71ff30a715b591228ca457c27ddf',1,'Plframe']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_72.js <==
var searchData=
[
  ['r',['r',['../structtriangle.html#a8c113023de81330c683c9c81f878e50c',1,'triangle::r()'],['../structcircle.html#a5f252f6cf93b81949dbf334c74931f18',1,'circle::r()'],['../structplplot_1_1__N9.html#a01fbe78b7661462acf48a6ef1e6f69f8',1,'plplot::_N9::r()'],['../structPLColor.html#a7b9027cf28c331d71c22b00b51676b66',1,'PLColor::r()']]],
  ['ranma',['ranma',['../structPLStream.html#aec2efdbc2ca51f988a82ce7ec78f0453',1,'PLStream']]],
  ['ranmi',['ranmi',['../structPLStream.html#a9dba1033a4c746fca6c24651ec6db2f7',1,'PLStream']]],
  ['rasterize_5fimage',['rasterize_image',['../structPLCairo.html#a8f1b530005cb096156a35e18bb8d779e',1,'PLCairo::rasterize_image()'],['../cairo_8c.html#acca2891d8180befce6f21603e0b1eea9',1,'rasterize_image():&#160;cairo.c']]],
  ['rband',['rband',['../structPlFrame.html#aa776906f93a788fa34b76bdda136966d',1,'PlFrame::rband()'],['../structPlPlotter.html#af9fc308a1e078617e9d7429b55c3b832',1,'PlPlotter::rband()']]],
  ['rband_5fpt',['rband_pt',['../structPlFrame.html#a917bc8ae7665e11c5ad9c957e82c26a5',1,'PlFrame::rband_pt()'],['../structPlPlotter.html#a64a6d749895142d0b745876e7bcd4530',1,'PlPlotter::rband_pt()']]],
  ['readlocation',['readLocation',['../structMemoryMapHeader.html#a022487f1b220085be636f72110928c7a',1,'MemoryMapHeader']]],
  ['red',['red',['../structcdImageStruct.html#a9c162fd0660559d959bbf9d90e3fc071',1,'cdImageStruct']]],
  ['refx',['refx',['../structEscText.html#a285ddb4ae4df1f679caac4f8da861d1e',1,'EscText']]],
  ['refy',['refy',['../structEscText.html#a139c59f7c3157c5f66f4e82dae4776ea',1,'EscText']]],
  ['relief',['relief',['../structPlFrame.html#a41508f51c2fb15d19c743dc7c2bea360',1,'PlFrame::relief()'],['../structPlPlotter.html#a77816130e2cf511b4c982239e9044f48',1,'PlPlotter::relief()']]],
  ['result',['result',['../structplplot_1_1__N11.html#aead102f090672f500c41981a2eebcdb1',1,'plplot::_N11::result()'],['../structPLBufferingCB.html#a30692e8a3aa17c0c8082a5d0c40328df',1,'PLBufferingCB::result()']]],
  ['return_5fcode',['return_code',['../tclAPI_8c.html#a934c111b1421c6aa91507fabd5c96deb',1,'tclAPI.c']]],
  ['rotate',['rotate',['../structarc__struct.html#ab0caa02f48b247f181d80573eef17d28',1,'arc_struct']]],
  ['rw_5fcmap',['rw_cmap',['../structXwDisplay.html#a84faf4f40f4aa3cf96710c956107e2af',1,'XwDisplay']]],
  ['rx',['rx',['../namespacePlframe.html#a3c48e474361f6fca6966964d609038fe',1,'Plframe']]],
  ['ry',['ry',['../namespacePlframe.html#afa4b71ff30a715b591228ca457c27ddf',1,'Plframe']]]
];
